Class

Struct Class 

pub struct Class<V: JSValueImpl>(/* private fields */);
Represents a JavaScript class constructor

This struct encapsulates a JavaScript object that serves as a class constructor. It is used to create class instances and manage class lifecycle.

Implementations

Source

impl<V> Class<V>

pub fn instance<JC: JSClass<V>>(self, value: JC) -> JSObject<V>

Create a new instance of the class

pub fn instance_of<JC: JSClass<V>>(object: &JSObject<V>) -> bool

Check if the object is an instance of the specified class

pub fn lookup<JC: JSClass<V>>(context: &JSContext<V::Context>) -> JSResult<Self>

Returns the registered constructor for a class type.

pub fn prototype<JC: JSClass<V>>( context: &JSContext<V::Context>, ) -> JSResult<JSObject<V>>

pub fn from_object<JC: JSClass<V>>(obj: &JSObject<V>) -> Option<Self>

Construct a Class constructor from a JSObject if it is an instance of the specified class

Arguments
  • obj - The JSObject to check and convert
Returns
  • Some(Class) if the object is an instance of the specified class
  • None if the object is not an instance of the specified class

Methods from Deref<Target = JSObject<V>>

pub fn borrow<T>(&self) -> JSResult<Ref<'_, T>>
where T: JSClass<V>,

Borrow the underlying data from an instance

pub fn borrow_mut<T>(&self) -> JSResult<RefMut<'_, T>>
where T: JSClass<V>,

Mutably borrow the underlying data from an instance

pub fn prototype(&self, proto: JSObject<V>) -> bool

pub fn to_json_string(&self) -> JSResult<String>

Convert JSObject to JSON string using JavaScript’s JSON.stringify

pub fn set<'a, K, KV>(&'a self, k: K, kv: KV) -> JSResult<&'a Self>
where K: Into<PropertyKey<'a, V>>, KV: IntoJSValue<V>,

pub fn define_property<'a, K>( &'a self, k: K, descriptor: PropertyDescriptor<V>, ) -> JSResult<&'a Self>
where K: Into<PropertyKey<'a, V>>,

pub fn delete<'a, K>(&'a self, k: K) -> JSResult<bool>
where K: Into<PropertyKey<'a, V>>,

pub fn has_property<'a, K>(&self, k: K) -> JSResult<bool>
where K: Into<PropertyKey<'a, V>>,

pub fn get<'a, K, T>(&'a self, k: K) -> JSResult<T>
where K: Into<PropertyKey<'a, V>>, T: FromJSValue<V>,

pub fn get_opt<'a, K, T>(&'a self, k: K) -> JSResult<Option<T>>
where K: Into<PropertyKey<'a, V>>, T: FromJSValue<V>,

pub fn as_js_value(&self) -> &JSValue<V>

pub fn entries(&self) -> JSResult<Vec<Entry<V>>>

Returns an iterator over the object’s own enumerable string-keyed property [key, value] pairs.

pub fn entries_as<K, V2>(&self) -> JSResult<Vec<(K, V2)>>
where K: FromJSValue<V>, V2: FromJSValue<V>,

Returns entries with converted types

pub fn own_keys(&self) -> JSResult<Vec<V>>

Returns an array of a given object’s own enumerable property names

pub fn values(&self) -> JSResult<impl Iterator<Item = JSValue<V>> + '_>

Returns an iterator over the object’s own enumerable string-keyed property values.

pub fn values_as<T>(&self) -> JSResult<Vec<T>>
where T: FromJSValue<V>,

Returns values with converted type

pub fn keys(&self) -> JSResult<impl Iterator<Item = JSValue<V>> + '_>

Returns an iterator over the object’s own enumerable string-keyed property names.

pub fn keys_as<K>(&self) -> JSResult<Vec<K>>
where K: FromJSValue<V>,

Returns keys with converted type

Methods from Deref<Target = JSValue<V>>

pub fn type_of(&self) -> JSValueType

pub fn is_object(&self) -> bool

pub fn is_array(&self) -> bool

pub fn is_array_buffer(&self) -> bool

pub fn is_function(&self) -> bool

pub fn is_constructor(&self) -> bool

pub fn is_promise(&self) -> bool

pub fn is_error(&self) -> bool

pub fn is_exception(&self) -> bool

pub fn is_undefined(&self) -> bool

pub fn is_null(&self) -> bool

pub fn is_boolean(&self) -> bool

pub fn is_number(&self) -> bool

pub fn is_bigint(&self) -> bool

pub fn is_string(&self) -> bool

pub fn is_symbol(&self) -> bool

pub fn is_date(&self) -> bool

pub fn is_proxy(&self) -> bool

pub fn as_value(&self) -> &V

pub fn context(&self) -> JSContext<V::Context>

Returns the context associated with this value.